@@ -12,13 +12,9 @@ from .minions import (
 from .master import create_master
 from .providers import provider_map
 from .roles import get_minion_arguments_for_role, get_provider_for_role
+from .utils import log_error, log_warning
 from .version import __version__
 
-class TerminalColors:
-    WARNING = '\033[33m'
-    FAIL = '\033[91m'
-    RESET = '\033[0m'
-
 
 def main(argv=None):
     try:
@@ -30,27 +26,6 @@ def main(argv=None):
         sys.exit(1)
 
 
-def log_warning(message, end='\n'):
-    log_to_stderr_with_color(message, TerminalColors.WARNING, end)
-
-
-def log_error(message, end='\n'):
-    log_to_stderr_with_color(message, TerminalColors.FAIL, end)
-
-
-def log_to_stderr_with_color(message, color, end):
-    out = sys.stderr
-    if out.isatty():
-        out.write(color)
-        out.write(message)
-        out.write(TerminalColors.RESET)
-    else:
-        out.write(message)
-    if end:
-        out.write(end)
-    out.flush()
-
-
 class DefaultArgumentString(str):
     # If this is used for default values in argparse we can detect when a
     # default is being used vs being set explicitly
@@ -66,7 +41,8 @@ class HartCLI:
 
 
     def get_args(self, argv):
-        parser = argparse.ArgumentParser(prog='hart', add_help=False)
+        # Define a conflict handler to let subclasses override defaults
+        parser = argparse.ArgumentParser(prog='hart', add_help=False, conflict_handler='resolve')
 
         parser.add_argument('-P', '--provider', choices=provider_map.keys(),
             help='Which VPS provider to use.')
