@@ -1,5 +1,4 @@
 import hashlib
-import re
 
 from libcloud.compute.providers import get_driver
 from libcloud.compute.types import Provider
@@ -33,10 +32,14 @@ region_pretty_names = {
     'us-east4': 'Ashburn, Northern Virginia, USA',
     'us-west1': 'The Dalles, Oregon, USA',
     'us-west2': 'Los Angeles, California, USA',
+    'us-west3': 'Salt Lake City, Utah, USA',
+    'us-west4': 'Las Vegas, Nevada, USA',
 }
 
 
 class GCEProvider(BaseLibcloudProvider):
+    alias = 'gce'
+    default_size = 'n1-standard-1'
 
     def __init__(self, user_id, key, project, region=None, **kwargs):
         constructor = get_driver(Provider.GCE)
@@ -105,11 +108,14 @@ class GCEProvider(BaseLibcloudProvider):
         parser.add_argument('-z', '--zone', help='GCE zone to launch in')
         parser.add_argument('-l', '--labels', type=split_csv_keyval,
             help='Comma-separated key=value pairs of labels to add to the node.')
+        parser.add_argument('--subnet', help='The subnet to launch in.')
         parser.add_argument('--volume-size', type=int, default=10,
             help='The size of the boot drive in GB, minimum 10')
         parser.add_argument('--volume-type', default='pd-ssd',
             help='Which volume type to use for the boot drive. Default: %(default)s',
             choices=('pd-standard', 'pd-ssd'))
+        parser.add_argument('--enable-oslogin', action='store_true',
+            help='By default OS Login is disabled, pass this flag to enable it for this minion')
         # To use the highest-performing disk on GCE (local ssd mounted over
         # NVMe) we need to mount multiple disks as that can't be the boot disk.
         # Decide on a CLI convention for specifying arbitrary additional disks.
@@ -124,16 +130,23 @@ class GCEProvider(BaseLibcloudProvider):
             cloud_init,
             private_networking,
             tags,
-            size='n1-standard-1',
+            size=None,
             **kwargs):
+        if size is None:
+            size = self.default_size
+
         zone = kwargs.get('zone')
         if not zone:
             raise UserError('You must specify the GCE zone to launch in')
 
+        subnet_string = kwargs.get('subnet')
+
         zone = self.driver.ex_get_zone(zone)
         image = self.driver.ex_get_image('debian-%d' % DEBIAN_VERSIONS[debian_codename])
         volume_type = kwargs.get('volume_type')
         disk_type = self.driver.ex_get_disktype(volume_type, zone=zone)
+        regional_subnets = self.driver.ex_list_subnetworks(region)
+        subnet = get_selected_or_default_subnet(regional_subnets, subnet_string)
         node = self.driver.create_node(
             name=name_from_minion_id(minion_id),
             size=size,
@@ -141,9 +154,14 @@ class GCEProvider(BaseLibcloudProvider):
             image=None, # Specified in the disk params
             description=minion_id,
             ex_tags=tags,
+            ex_network=subnet.network,
+            ex_subnetwork=subnet,
             ex_metadata={
                 'sshKeys': auth_key,
                 'startup-script': cloud_init,
+                # We assume that if you manage servers with salt you want to use salt to
+                # manage ssh access, but we allow this to be overridden
+                'enable-oslogin': kwargs.get('enable_oslogin', False),
             },
             ex_labels=kwargs.get('labels'),
             ex_disks_gce_struct=[{
@@ -170,7 +188,7 @@ class GCEProvider(BaseLibcloudProvider):
             print(line, end='')
             # TODO: This doesn't detect if the init script failed for some reason, need
             # to find a reliable way to do that
-            if 'Hart init script complete' in line:
+            if 'hart-init-complete' in line:
                 stdout.channel.close()
                 client.exec_command('kill %d' % tail_pid)
                 break
@@ -200,3 +218,21 @@ def name_from_minion_id(minion_id):
     sanitized_name = minion_id.replace('.', '-')
     hashed_id = hashlib.sha256(minion_id.encode('utf-8')).hexdigest()
     return 'hart-%s-%s' % (sanitized_name[:47], hashed_id[:10])
+
+
+def get_selected_or_default_subnet(subnets, subnet_string):
+    if not subnets:
+        raise UserError('No subnets available in the given region')
+
+    if subnet_string is None and len(subnets) == 1:
+        return subnets[0]
+    elif subnet_string is None:
+        raise UserError('More than one subnet available in %s, need to pick one of %s' % (
+            subnets[0].region.name, ', '.join(s.name for s in subnets)))
+
+    for subnet in subnets:
+        if subnet.name == subnet_string:
+            return subnet
+
+    raise UserError('None of the subnets in %s match %r, should be one of %s' % (
+        subnets[0].region.name, subnet_string, ', '.join(s.name for s in subnets)))
